__title__ = 'proxier'
__description__ = 'Get a Proxy server address easily'
__url__ = 'https://github.com/fredericowu/proxier'
__version__ = '0.2.0'
__author__ = 'Frederico Dias Wu'
__author_email__ = 'fredericowu@gmail.com'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2020 Frederico Dias Wu'
